"""
Main interface for macie2 service type definitions.

Usage::

    ```python
    from mypy_boto3_macie2.type_defs import AccessControlListTypeDef

    data: AccessControlListTypeDef = {...}
    ```
"""
import sys
from datetime import datetime
from typing import Any, Dict, List

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal

if sys.version_info >= (3, 8):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "AccessControlListTypeDef",
    "AccountLevelPermissionsTypeDef",
    "AdminAccountTypeDef",
    "ApiCallDetailsTypeDef",
    "AssumedRoleTypeDef",
    "AwsAccountTypeDef",
    "AwsServiceTypeDef",
    "BatchGetCustomDataIdentifierSummaryTypeDef",
    "BlockPublicAccessTypeDef",
    "BucketCountByEffectivePermissionTypeDef",
    "BucketCountByEncryptionTypeTypeDef",
    "BucketCountBySharedAccessTypeTypeDef",
    "BucketLevelPermissionsTypeDef",
    "BucketMetadataTypeDef",
    "BucketPermissionConfigurationTypeDef",
    "BucketPolicyTypeDef",
    "BucketPublicAccessTypeDef",
    "ClassificationDetailsTypeDef",
    "ClassificationExportConfigurationTypeDef",
    "ClassificationResultStatusTypeDef",
    "ClassificationResultTypeDef",
    "CriterionAdditionalPropertiesTypeDef",
    "CustomDataIdentifierSummaryTypeDef",
    "CustomDataIdentifiersTypeDef",
    "CustomDetectionTypeDef",
    "DefaultDetectionTypeDef",
    "DomainDetailsTypeDef",
    "FederatedUserTypeDef",
    "FindingActionTypeDef",
    "FindingActorTypeDef",
    "FindingCriteriaTypeDef",
    "FindingTypeDef",
    "FindingsFilterListItemTypeDef",
    "GroupCountTypeDef",
    "IamUserTypeDef",
    "InvitationTypeDef",
    "IpAddressDetailsTypeDef",
    "IpCityTypeDef",
    "IpCountryTypeDef",
    "IpGeoLocationTypeDef",
    "IpOwnerTypeDef",
    "JobScheduleFrequencyTypeDef",
    "JobScopeTermTypeDef",
    "JobScopingBlockTypeDef",
    "JobSummaryTypeDef",
    "KeyValuePairTypeDef",
    "ListJobsFilterTermTypeDef",
    "MemberTypeDef",
    "MonthlyScheduleTypeDef",
    "ObjectCountByEncryptionTypeTypeDef",
    "PolicyDetailsTypeDef",
    "ReplicationDetailsTypeDef",
    "ResourcesAffectedTypeDef",
    "S3BucketDefinitionForJobTypeDef",
    "S3BucketOwnerTypeDef",
    "S3BucketTypeDef",
    "S3DestinationTypeDef",
    "S3JobDefinitionTypeDef",
    "S3ObjectTypeDef",
    "ScopingTypeDef",
    "SensitiveDataItemTypeDef",
    "ServerSideEncryptionTypeDef",
    "ServiceLimitTypeDef",
    "SessionContextAttributesTypeDef",
    "SessionContextTypeDef",
    "SessionIssuerTypeDef",
    "SeverityTypeDef",
    "SimpleScopeTermTypeDef",
    "StatisticsTypeDef",
    "TagScopeTermTypeDef",
    "TagValuePairTypeDef",
    "UnprocessedAccountTypeDef",
    "UsageByAccountTypeDef",
    "UsageRecordTypeDef",
    "UsageTotalTypeDef",
    "UserIdentityRootTypeDef",
    "UserIdentityTypeDef",
    "WeeklyScheduleTypeDef",
    "AccountDetailTypeDef",
    "BatchGetCustomDataIdentifiersResponseTypeDef",
    "BucketCriteriaAdditionalPropertiesTypeDef",
    "BucketSortCriteriaTypeDef",
    "CreateClassificationJobResponseTypeDef",
    "CreateCustomDataIdentifierResponseTypeDef",
    "CreateFindingsFilterResponseTypeDef",
    "CreateInvitationsResponseTypeDef",
    "CreateMemberResponseTypeDef",
    "DeclineInvitationsResponseTypeDef",
    "DeleteInvitationsResponseTypeDef",
    "DescribeBucketsResponseTypeDef",
    "DescribeClassificationJobResponseTypeDef",
    "DescribeOrganizationConfigurationResponseTypeDef",
    "FindingStatisticsSortCriteriaTypeDef",
    "GetBucketStatisticsResponseTypeDef",
    "GetClassificationExportConfigurationResponseTypeDef",
    "GetCustomDataIdentifierResponseTypeDef",
    "GetFindingStatisticsResponseTypeDef",
    "GetFindingsFilterResponseTypeDef",
    "GetFindingsResponseTypeDef",
    "GetInvitationsCountResponseTypeDef",
    "GetMacieSessionResponseTypeDef",
    "GetMasterAccountResponseTypeDef",
    "GetMemberResponseTypeDef",
    "GetUsageStatisticsResponseTypeDef",
    "GetUsageTotalsResponseTypeDef",
    "ListClassificationJobsResponseTypeDef",
    "ListCustomDataIdentifiersResponseTypeDef",
    "ListFindingsFiltersResponseTypeDef",
    "ListFindingsResponseTypeDef",
    "ListInvitationsResponseTypeDef",
    "ListJobsFilterCriteriaTypeDef",
    "ListJobsSortCriteriaTypeDef",
    "ListMembersResponseTypeDef",
    "ListOrganizationAdminAccountsResponseTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "PutClassificationExportConfigurationResponseTypeDef",
    "SortCriteriaTypeDef",
    "TestCustomDataIdentifierResponseTypeDef",
    "UpdateFindingsFilterResponseTypeDef",
    "UsageStatisticsFilterTypeDef",
    "UsageStatisticsSortByTypeDef",
)

AccessControlListTypeDef = TypedDict(
    "AccessControlListTypeDef",
    {"allowsPublicReadAccess": bool, "allowsPublicWriteAccess": bool},
    total=False,
)

AccountLevelPermissionsTypeDef = TypedDict(
    "AccountLevelPermissionsTypeDef", {"blockPublicAccess": "BlockPublicAccessTypeDef"}, total=False
)

AdminAccountTypeDef = TypedDict(
    "AdminAccountTypeDef",
    {"accountId": str, "status": Literal["ENABLED", "DISABLING_IN_PROGRESS"]},
    total=False,
)

ApiCallDetailsTypeDef = TypedDict(
    "ApiCallDetailsTypeDef",
    {"api": str, "apiServiceName": str, "firstSeen": datetime, "lastSeen": datetime},
    total=False,
)

AssumedRoleTypeDef = TypedDict(
    "AssumedRoleTypeDef",
    {
        "accessKeyId": str,
        "accountId": str,
        "arn": str,
        "principalId": str,
        "sessionContext": "SessionContextTypeDef",
    },
    total=False,
)

AwsAccountTypeDef = TypedDict(
    "AwsAccountTypeDef", {"accountId": str, "principalId": str}, total=False
)

AwsServiceTypeDef = TypedDict("AwsServiceTypeDef", {"invokedBy": str}, total=False)

BatchGetCustomDataIdentifierSummaryTypeDef = TypedDict(
    "BatchGetCustomDataIdentifierSummaryTypeDef",
    {
        "arn": str,
        "createdAt": datetime,
        "deleted": bool,
        "description": str,
        "id": str,
        "name": str,
    },
    total=False,
)

BlockPublicAccessTypeDef = TypedDict(
    "BlockPublicAccessTypeDef",
    {
        "blockPublicAcls": bool,
        "blockPublicPolicy": bool,
        "ignorePublicAcls": bool,
        "restrictPublicBuckets": bool,
    },
    total=False,
)

BucketCountByEffectivePermissionTypeDef = TypedDict(
    "BucketCountByEffectivePermissionTypeDef",
    {"publiclyAccessible": int, "publiclyReadable": int, "publiclyWritable": int},
    total=False,
)

BucketCountByEncryptionTypeTypeDef = TypedDict(
    "BucketCountByEncryptionTypeTypeDef",
    {"kmsManaged": int, "s3Managed": int, "unencrypted": int},
    total=False,
)

BucketCountBySharedAccessTypeTypeDef = TypedDict(
    "BucketCountBySharedAccessTypeTypeDef",
    {"external": int, "internal": int, "notShared": int},
    total=False,
)

BucketLevelPermissionsTypeDef = TypedDict(
    "BucketLevelPermissionsTypeDef",
    {
        "accessControlList": "AccessControlListTypeDef",
        "blockPublicAccess": "BlockPublicAccessTypeDef",
        "bucketPolicy": "BucketPolicyTypeDef",
    },
    total=False,
)

BucketMetadataTypeDef = TypedDict(
    "BucketMetadataTypeDef",
    {
        "accountId": str,
        "bucketArn": str,
        "bucketCreatedAt": datetime,
        "bucketName": str,
        "classifiableObjectCount": int,
        "lastUpdated": datetime,
        "objectCount": int,
        "objectCountByEncryptionType": "ObjectCountByEncryptionTypeTypeDef",
        "publicAccess": "BucketPublicAccessTypeDef",
        "region": str,
        "replicationDetails": "ReplicationDetailsTypeDef",
        "sharedAccess": Literal["EXTERNAL", "INTERNAL", "NOT_SHARED"],
        "sizeInBytes": int,
        "sizeInBytesCompressed": int,
        "tags": List["KeyValuePairTypeDef"],
        "versioning": bool,
    },
    total=False,
)

BucketPermissionConfigurationTypeDef = TypedDict(
    "BucketPermissionConfigurationTypeDef",
    {
        "accountLevelPermissions": "AccountLevelPermissionsTypeDef",
        "bucketLevelPermissions": "BucketLevelPermissionsTypeDef",
    },
    total=False,
)

BucketPolicyTypeDef = TypedDict(
    "BucketPolicyTypeDef",
    {"allowsPublicReadAccess": bool, "allowsPublicWriteAccess": bool},
    total=False,
)

BucketPublicAccessTypeDef = TypedDict(
    "BucketPublicAccessTypeDef",
    {
        "effectivePermission": Literal["PUBLIC", "NOT_PUBLIC"],
        "permissionConfiguration": "BucketPermissionConfigurationTypeDef",
    },
    total=False,
)

ClassificationDetailsTypeDef = TypedDict(
    "ClassificationDetailsTypeDef",
    {
        "detailedResultsLocation": str,
        "jobArn": str,
        "jobId": str,
        "result": "ClassificationResultTypeDef",
    },
    total=False,
)

ClassificationExportConfigurationTypeDef = TypedDict(
    "ClassificationExportConfigurationTypeDef",
    {"s3Destination": "S3DestinationTypeDef"},
    total=False,
)

ClassificationResultStatusTypeDef = TypedDict(
    "ClassificationResultStatusTypeDef", {"code": str, "reason": str}, total=False
)

ClassificationResultTypeDef = TypedDict(
    "ClassificationResultTypeDef",
    {
        "customDataIdentifiers": "CustomDataIdentifiersTypeDef",
        "mimeType": str,
        "sensitiveData": List["SensitiveDataItemTypeDef"],
        "sizeClassified": int,
        "status": "ClassificationResultStatusTypeDef",
    },
    total=False,
)

CriterionAdditionalPropertiesTypeDef = TypedDict(
    "CriterionAdditionalPropertiesTypeDef",
    {"eq": List[str], "gt": int, "gte": int, "lt": int, "lte": int, "neq": List[str]},
    total=False,
)

CustomDataIdentifierSummaryTypeDef = TypedDict(
    "CustomDataIdentifierSummaryTypeDef",
    {"arn": str, "createdAt": datetime, "description": str, "id": str, "name": str},
    total=False,
)

CustomDataIdentifiersTypeDef = TypedDict(
    "CustomDataIdentifiersTypeDef",
    {"detections": List["CustomDetectionTypeDef"], "totalCount": int},
    total=False,
)

CustomDetectionTypeDef = TypedDict(
    "CustomDetectionTypeDef", {"arn": str, "count": int, "name": str}, total=False
)

DefaultDetectionTypeDef = TypedDict(
    "DefaultDetectionTypeDef", {"count": int, "type": str}, total=False
)

DomainDetailsTypeDef = TypedDict("DomainDetailsTypeDef", {"domainName": str}, total=False)

FederatedUserTypeDef = TypedDict(
    "FederatedUserTypeDef",
    {
        "accessKeyId": str,
        "accountId": str,
        "arn": str,
        "principalId": str,
        "sessionContext": "SessionContextTypeDef",
    },
    total=False,
)

FindingActionTypeDef = TypedDict(
    "FindingActionTypeDef",
    {"actionType": Literal["AWS_API_CALL"], "apiCallDetails": "ApiCallDetailsTypeDef"},
    total=False,
)

FindingActorTypeDef = TypedDict(
    "FindingActorTypeDef",
    {
        "domainDetails": "DomainDetailsTypeDef",
        "ipAddressDetails": "IpAddressDetailsTypeDef",
        "userIdentity": "UserIdentityTypeDef",
    },
    total=False,
)

FindingCriteriaTypeDef = TypedDict(
    "FindingCriteriaTypeDef",
    {"criterion": Dict[str, "CriterionAdditionalPropertiesTypeDef"]},
    total=False,
)

FindingTypeDef = TypedDict(
    "FindingTypeDef",
    {
        "accountId": str,
        "archived": bool,
        "category": Literal["CLASSIFICATION", "POLICY"],
        "classificationDetails": "ClassificationDetailsTypeDef",
        "count": int,
        "createdAt": datetime,
        "description": str,
        "id": str,
        "partition": str,
        "policyDetails": "PolicyDetailsTypeDef",
        "region": str,
        "resourcesAffected": "ResourcesAffectedTypeDef",
        "sample": bool,
        "schemaVersion": str,
        "severity": "SeverityTypeDef",
        "title": str,
        "type": Literal[
            "SensitiveData:S3Object/Multiple",
            "SensitiveData:S3Object/Financial",
            "SensitiveData:S3Object/Personal",
            "SensitiveData:S3Object/Credentials",
            "SensitiveData:S3Object/CustomIdentifier",
            "Policy:IAMUser/S3BucketPublic",
            "Policy:IAMUser/S3BucketSharedExternally",
            "Policy:IAMUser/S3BucketReplicatedExternally",
            "Policy:IAMUser/S3BucketEncryptionDisabled",
            "Policy:IAMUser/S3BlockPublicAccessDisabled",
        ],
        "updatedAt": datetime,
    },
    total=False,
)

FindingsFilterListItemTypeDef = TypedDict(
    "FindingsFilterListItemTypeDef",
    {"arn": str, "id": str, "name": str, "tags": Dict[str, str]},
    total=False,
)

GroupCountTypeDef = TypedDict("GroupCountTypeDef", {"count": int, "groupKey": str}, total=False)

IamUserTypeDef = TypedDict(
    "IamUserTypeDef",
    {"accountId": str, "arn": str, "principalId": str, "userName": str},
    total=False,
)

InvitationTypeDef = TypedDict(
    "InvitationTypeDef",
    {
        "accountId": str,
        "invitationId": str,
        "invitedAt": datetime,
        "relationshipStatus": Literal[
            "Enabled",
            "Paused",
            "Invited",
            "Created",
            "Removed",
            "Resigned",
            "EmailVerificationInProgress",
            "EmailVerificationFailed",
        ],
    },
    total=False,
)

IpAddressDetailsTypeDef = TypedDict(
    "IpAddressDetailsTypeDef",
    {
        "ipAddressV4": str,
        "ipCity": "IpCityTypeDef",
        "ipCountry": "IpCountryTypeDef",
        "ipGeoLocation": "IpGeoLocationTypeDef",
        "ipOwner": "IpOwnerTypeDef",
    },
    total=False,
)

IpCityTypeDef = TypedDict("IpCityTypeDef", {"name": str}, total=False)

IpCountryTypeDef = TypedDict("IpCountryTypeDef", {"code": str, "name": str}, total=False)

IpGeoLocationTypeDef = TypedDict("IpGeoLocationTypeDef", {"lat": float, "lon": float}, total=False)

IpOwnerTypeDef = TypedDict(
    "IpOwnerTypeDef", {"asn": str, "asnOrg": str, "isp": str, "org": str}, total=False
)

JobScheduleFrequencyTypeDef = TypedDict(
    "JobScheduleFrequencyTypeDef",
    {
        "dailySchedule": Dict[str, Any],
        "monthlySchedule": "MonthlyScheduleTypeDef",
        "weeklySchedule": "WeeklyScheduleTypeDef",
    },
    total=False,
)

JobScopeTermTypeDef = TypedDict(
    "JobScopeTermTypeDef",
    {"simpleScopeTerm": "SimpleScopeTermTypeDef", "tagScopeTerm": "TagScopeTermTypeDef"},
    total=False,
)

JobScopingBlockTypeDef = TypedDict(
    "JobScopingBlockTypeDef", {"and": List["JobScopeTermTypeDef"]}, total=False
)

JobSummaryTypeDef = TypedDict(
    "JobSummaryTypeDef",
    {
        "bucketDefinitions": List["S3BucketDefinitionForJobTypeDef"],
        "createdAt": datetime,
        "jobId": str,
        "jobStatus": Literal["RUNNING", "PAUSED", "CANCELLED", "COMPLETE", "IDLE"],
        "jobType": Literal["ONE_TIME", "SCHEDULED"],
        "name": str,
    },
    total=False,
)

KeyValuePairTypeDef = TypedDict("KeyValuePairTypeDef", {"key": str, "value": str}, total=False)

ListJobsFilterTermTypeDef = TypedDict(
    "ListJobsFilterTermTypeDef",
    {
        "comparator": Literal["EQ", "GT", "GTE", "LT", "LTE", "NE", "CONTAINS"],
        "key": Literal["jobType", "jobStatus", "createdAt", "name"],
        "values": List[str],
    },
    total=False,
)

MemberTypeDef = TypedDict(
    "MemberTypeDef",
    {
        "accountId": str,
        "arn": str,
        "email": str,
        "invitedAt": datetime,
        "masterAccountId": str,
        "relationshipStatus": Literal[
            "Enabled",
            "Paused",
            "Invited",
            "Created",
            "Removed",
            "Resigned",
            "EmailVerificationInProgress",
            "EmailVerificationFailed",
        ],
        "tags": Dict[str, str],
        "updatedAt": datetime,
    },
    total=False,
)

MonthlyScheduleTypeDef = TypedDict("MonthlyScheduleTypeDef", {"dayOfMonth": int}, total=False)

ObjectCountByEncryptionTypeTypeDef = TypedDict(
    "ObjectCountByEncryptionTypeTypeDef",
    {"customerManaged": int, "kmsManaged": int, "s3Managed": int, "unencrypted": int},
    total=False,
)

PolicyDetailsTypeDef = TypedDict(
    "PolicyDetailsTypeDef",
    {"action": "FindingActionTypeDef", "actor": "FindingActorTypeDef"},
    total=False,
)

ReplicationDetailsTypeDef = TypedDict(
    "ReplicationDetailsTypeDef",
    {"replicated": bool, "replicatedExternally": bool, "replicationAccounts": List[str]},
    total=False,
)

ResourcesAffectedTypeDef = TypedDict(
    "ResourcesAffectedTypeDef",
    {"s3Bucket": "S3BucketTypeDef", "s3Object": "S3ObjectTypeDef"},
    total=False,
)

S3BucketDefinitionForJobTypeDef = TypedDict(
    "S3BucketDefinitionForJobTypeDef", {"accountId": str, "buckets": List[str]}, total=False
)

S3BucketOwnerTypeDef = TypedDict(
    "S3BucketOwnerTypeDef", {"displayName": str, "id": str}, total=False
)

S3BucketTypeDef = TypedDict(
    "S3BucketTypeDef",
    {
        "arn": str,
        "createdAt": datetime,
        "defaultServerSideEncryption": "ServerSideEncryptionTypeDef",
        "name": str,
        "owner": "S3BucketOwnerTypeDef",
        "publicAccess": "BucketPublicAccessTypeDef",
        "tags": List["KeyValuePairTypeDef"],
    },
    total=False,
)

_RequiredS3DestinationTypeDef = TypedDict(
    "_RequiredS3DestinationTypeDef", {"bucketName": str, "kmsKeyArn": str}
)
_OptionalS3DestinationTypeDef = TypedDict(
    "_OptionalS3DestinationTypeDef", {"keyPrefix": str}, total=False
)


class S3DestinationTypeDef(_RequiredS3DestinationTypeDef, _OptionalS3DestinationTypeDef):
    pass


S3JobDefinitionTypeDef = TypedDict(
    "S3JobDefinitionTypeDef",
    {"bucketDefinitions": List["S3BucketDefinitionForJobTypeDef"], "scoping": "ScopingTypeDef"},
    total=False,
)

S3ObjectTypeDef = TypedDict(
    "S3ObjectTypeDef",
    {
        "bucketArn": str,
        "eTag": str,
        "extension": str,
        "key": str,
        "lastModified": datetime,
        "path": str,
        "publicAccess": bool,
        "serverSideEncryption": "ServerSideEncryptionTypeDef",
        "size": int,
        "storageClass": Literal[
            "STANDARD",
            "REDUCED_REDUNDANCY",
            "STANDARD_IA",
            "INTELLIGENT_TIERING",
            "DEEP_ARCHIVE",
            "ONEZONE_IA",
            "GLACIER",
        ],
        "tags": List["KeyValuePairTypeDef"],
        "versionId": str,
    },
    total=False,
)

ScopingTypeDef = TypedDict(
    "ScopingTypeDef",
    {"excludes": "JobScopingBlockTypeDef", "includes": "JobScopingBlockTypeDef"},
    total=False,
)

SensitiveDataItemTypeDef = TypedDict(
    "SensitiveDataItemTypeDef",
    {
        "category": Literal[
            "FINANCIAL_INFORMATION", "PERSONAL_INFORMATION", "CREDENTIALS", "CUSTOM_IDENTIFIER"
        ],
        "detections": List["DefaultDetectionTypeDef"],
        "totalCount": int,
    },
    total=False,
)

ServerSideEncryptionTypeDef = TypedDict(
    "ServerSideEncryptionTypeDef",
    {"encryptionType": Literal["NONE", "AES256", "aws:kms", "UNKNOWN"], "kmsMasterKeyId": str},
    total=False,
)

ServiceLimitTypeDef = TypedDict(
    "ServiceLimitTypeDef",
    {"isServiceLimited": bool, "unit": Literal["TERABYTES"], "value": int},
    total=False,
)

SessionContextAttributesTypeDef = TypedDict(
    "SessionContextAttributesTypeDef",
    {"creationDate": datetime, "mfaAuthenticated": bool},
    total=False,
)

SessionContextTypeDef = TypedDict(
    "SessionContextTypeDef",
    {"attributes": "SessionContextAttributesTypeDef", "sessionIssuer": "SessionIssuerTypeDef"},
    total=False,
)

SessionIssuerTypeDef = TypedDict(
    "SessionIssuerTypeDef",
    {"accountId": str, "arn": str, "principalId": str, "type": str, "userName": str},
    total=False,
)

SeverityTypeDef = TypedDict(
    "SeverityTypeDef", {"description": Literal["Low", "Medium", "High"], "score": int}, total=False
)

SimpleScopeTermTypeDef = TypedDict(
    "SimpleScopeTermTypeDef",
    {
        "comparator": Literal["EQ", "GT", "GTE", "LT", "LTE", "NE", "CONTAINS"],
        "key": Literal[
            "BUCKET_CREATION_DATE",
            "OBJECT_EXTENSION",
            "OBJECT_LAST_MODIFIED_DATE",
            "OBJECT_SIZE",
            "TAG",
        ],
        "values": List[str],
    },
    total=False,
)

StatisticsTypeDef = TypedDict(
    "StatisticsTypeDef",
    {"approximateNumberOfObjectsToProcess": float, "numberOfRuns": float},
    total=False,
)

TagScopeTermTypeDef = TypedDict(
    "TagScopeTermTypeDef",
    {
        "comparator": Literal["EQ", "GT", "GTE", "LT", "LTE", "NE", "CONTAINS"],
        "key": str,
        "tagValues": List["TagValuePairTypeDef"],
        "target": Literal["S3_OBJECT"],
    },
    total=False,
)

TagValuePairTypeDef = TypedDict("TagValuePairTypeDef", {"key": str, "value": str}, total=False)

UnprocessedAccountTypeDef = TypedDict(
    "UnprocessedAccountTypeDef",
    {"accountId": str, "errorCode": Literal["ClientError", "InternalError"], "errorMessage": str},
    total=False,
)

UsageByAccountTypeDef = TypedDict(
    "UsageByAccountTypeDef",
    {
        "currency": Literal["USD"],
        "estimatedCost": str,
        "serviceLimit": "ServiceLimitTypeDef",
        "type": Literal["DATA_INVENTORY_EVALUATION", "SENSITIVE_DATA_DISCOVERY"],
    },
    total=False,
)

UsageRecordTypeDef = TypedDict(
    "UsageRecordTypeDef",
    {"accountId": str, "freeTrialStartDate": datetime, "usage": List["UsageByAccountTypeDef"]},
    total=False,
)

UsageTotalTypeDef = TypedDict(
    "UsageTotalTypeDef",
    {
        "currency": Literal["USD"],
        "estimatedCost": str,
        "type": Literal["DATA_INVENTORY_EVALUATION", "SENSITIVE_DATA_DISCOVERY"],
    },
    total=False,
)

UserIdentityRootTypeDef = TypedDict(
    "UserIdentityRootTypeDef", {"accountId": str, "arn": str, "principalId": str}, total=False
)

UserIdentityTypeDef = TypedDict(
    "UserIdentityTypeDef",
    {
        "assumedRole": "AssumedRoleTypeDef",
        "awsAccount": "AwsAccountTypeDef",
        "awsService": "AwsServiceTypeDef",
        "federatedUser": "FederatedUserTypeDef",
        "iamUser": "IamUserTypeDef",
        "root": "UserIdentityRootTypeDef",
        "type": Literal[
            "AssumedRole", "IAMUser", "FederatedUser", "Root", "AWSAccount", "AWSService"
        ],
    },
    total=False,
)

WeeklyScheduleTypeDef = TypedDict(
    "WeeklyScheduleTypeDef",
    {
        "dayOfWeek": Literal[
            "SUNDAY", "MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY"
        ]
    },
    total=False,
)

AccountDetailTypeDef = TypedDict("AccountDetailTypeDef", {"accountId": str, "email": str})

BatchGetCustomDataIdentifiersResponseTypeDef = TypedDict(
    "BatchGetCustomDataIdentifiersResponseTypeDef",
    {
        "customDataIdentifiers": List["BatchGetCustomDataIdentifierSummaryTypeDef"],
        "notFoundIdentifierIds": List[str],
    },
    total=False,
)

BucketCriteriaAdditionalPropertiesTypeDef = TypedDict(
    "BucketCriteriaAdditionalPropertiesTypeDef",
    {
        "eq": List[str],
        "gt": int,
        "gte": int,
        "lt": int,
        "lte": int,
        "neq": List[str],
        "prefix": str,
    },
    total=False,
)

BucketSortCriteriaTypeDef = TypedDict(
    "BucketSortCriteriaTypeDef",
    {"attributeName": str, "orderBy": Literal["ASC", "DESC"]},
    total=False,
)

CreateClassificationJobResponseTypeDef = TypedDict(
    "CreateClassificationJobResponseTypeDef", {"jobArn": str, "jobId": str}, total=False
)

CreateCustomDataIdentifierResponseTypeDef = TypedDict(
    "CreateCustomDataIdentifierResponseTypeDef", {"customDataIdentifierId": str}, total=False
)

CreateFindingsFilterResponseTypeDef = TypedDict(
    "CreateFindingsFilterResponseTypeDef", {"arn": str, "id": str}, total=False
)

CreateInvitationsResponseTypeDef = TypedDict(
    "CreateInvitationsResponseTypeDef",
    {"unprocessedAccounts": List["UnprocessedAccountTypeDef"]},
    total=False,
)

CreateMemberResponseTypeDef = TypedDict("CreateMemberResponseTypeDef", {"arn": str}, total=False)

DeclineInvitationsResponseTypeDef = TypedDict(
    "DeclineInvitationsResponseTypeDef",
    {"unprocessedAccounts": List["UnprocessedAccountTypeDef"]},
    total=False,
)

DeleteInvitationsResponseTypeDef = TypedDict(
    "DeleteInvitationsResponseTypeDef",
    {"unprocessedAccounts": List["UnprocessedAccountTypeDef"]},
    total=False,
)

DescribeBucketsResponseTypeDef = TypedDict(
    "DescribeBucketsResponseTypeDef",
    {"buckets": List["BucketMetadataTypeDef"], "nextToken": str},
    total=False,
)

DescribeClassificationJobResponseTypeDef = TypedDict(
    "DescribeClassificationJobResponseTypeDef",
    {
        "clientToken": str,
        "createdAt": datetime,
        "customDataIdentifierIds": List[str],
        "description": str,
        "initialRun": bool,
        "jobArn": str,
        "jobId": str,
        "jobStatus": Literal["RUNNING", "PAUSED", "CANCELLED", "COMPLETE", "IDLE"],
        "jobType": Literal["ONE_TIME", "SCHEDULED"],
        "lastRunTime": datetime,
        "name": str,
        "s3JobDefinition": "S3JobDefinitionTypeDef",
        "samplingPercentage": int,
        "scheduleFrequency": "JobScheduleFrequencyTypeDef",
        "statistics": "StatisticsTypeDef",
        "tags": Dict[str, str],
    },
    total=False,
)

DescribeOrganizationConfigurationResponseTypeDef = TypedDict(
    "DescribeOrganizationConfigurationResponseTypeDef",
    {"autoEnable": bool, "maxAccountLimitReached": bool},
    total=False,
)

FindingStatisticsSortCriteriaTypeDef = TypedDict(
    "FindingStatisticsSortCriteriaTypeDef",
    {"attributeName": Literal["groupKey", "count"], "orderBy": Literal["ASC", "DESC"]},
    total=False,
)

GetBucketStatisticsResponseTypeDef = TypedDict(
    "GetBucketStatisticsResponseTypeDef",
    {
        "bucketCount": int,
        "bucketCountByEffectivePermission": "BucketCountByEffectivePermissionTypeDef",
        "bucketCountByEncryptionType": "BucketCountByEncryptionTypeTypeDef",
        "bucketCountBySharedAccessType": "BucketCountBySharedAccessTypeTypeDef",
        "classifiableObjectCount": int,
        "lastUpdated": datetime,
        "objectCount": int,
        "sizeInBytes": int,
        "sizeInBytesCompressed": int,
    },
    total=False,
)

GetClassificationExportConfigurationResponseTypeDef = TypedDict(
    "GetClassificationExportConfigurationResponseTypeDef",
    {"configuration": "ClassificationExportConfigurationTypeDef"},
    total=False,
)

GetCustomDataIdentifierResponseTypeDef = TypedDict(
    "GetCustomDataIdentifierResponseTypeDef",
    {
        "arn": str,
        "createdAt": datetime,
        "deleted": bool,
        "description": str,
        "id": str,
        "ignoreWords": List[str],
        "keywords": List[str],
        "maximumMatchDistance": int,
        "name": str,
        "regex": str,
        "tags": Dict[str, str],
    },
    total=False,
)

GetFindingStatisticsResponseTypeDef = TypedDict(
    "GetFindingStatisticsResponseTypeDef", {"countsByGroup": List["GroupCountTypeDef"]}, total=False
)

GetFindingsFilterResponseTypeDef = TypedDict(
    "GetFindingsFilterResponseTypeDef",
    {
        "action": Literal["ARCHIVE", "NOOP"],
        "arn": str,
        "description": str,
        "findingCriteria": "FindingCriteriaTypeDef",
        "id": str,
        "name": str,
        "position": int,
        "tags": Dict[str, str],
    },
    total=False,
)

GetFindingsResponseTypeDef = TypedDict(
    "GetFindingsResponseTypeDef", {"findings": List["FindingTypeDef"]}, total=False
)

GetInvitationsCountResponseTypeDef = TypedDict(
    "GetInvitationsCountResponseTypeDef", {"invitationsCount": int}, total=False
)

GetMacieSessionResponseTypeDef = TypedDict(
    "GetMacieSessionResponseTypeDef",
    {
        "createdAt": datetime,
        "findingPublishingFrequency": Literal["FIFTEEN_MINUTES", "ONE_HOUR", "SIX_HOURS"],
        "serviceRole": str,
        "status": Literal["PAUSED", "ENABLED"],
        "updatedAt": datetime,
    },
    total=False,
)

GetMasterAccountResponseTypeDef = TypedDict(
    "GetMasterAccountResponseTypeDef", {"master": "InvitationTypeDef"}, total=False
)

GetMemberResponseTypeDef = TypedDict(
    "GetMemberResponseTypeDef",
    {
        "accountId": str,
        "arn": str,
        "email": str,
        "invitedAt": datetime,
        "masterAccountId": str,
        "relationshipStatus": Literal[
            "Enabled",
            "Paused",
            "Invited",
            "Created",
            "Removed",
            "Resigned",
            "EmailVerificationInProgress",
            "EmailVerificationFailed",
        ],
        "tags": Dict[str, str],
        "updatedAt": datetime,
    },
    total=False,
)

GetUsageStatisticsResponseTypeDef = TypedDict(
    "GetUsageStatisticsResponseTypeDef",
    {"nextToken": str, "records": List["UsageRecordTypeDef"]},
    total=False,
)

GetUsageTotalsResponseTypeDef = TypedDict(
    "GetUsageTotalsResponseTypeDef", {"usageTotals": List["UsageTotalTypeDef"]}, total=False
)

ListClassificationJobsResponseTypeDef = TypedDict(
    "ListClassificationJobsResponseTypeDef",
    {"items": List["JobSummaryTypeDef"], "nextToken": str},
    total=False,
)

ListCustomDataIdentifiersResponseTypeDef = TypedDict(
    "ListCustomDataIdentifiersResponseTypeDef",
    {"items": List["CustomDataIdentifierSummaryTypeDef"], "nextToken": str},
    total=False,
)

ListFindingsFiltersResponseTypeDef = TypedDict(
    "ListFindingsFiltersResponseTypeDef",
    {"findingsFilterListItems": List["FindingsFilterListItemTypeDef"], "nextToken": str},
    total=False,
)

ListFindingsResponseTypeDef = TypedDict(
    "ListFindingsResponseTypeDef", {"findingIds": List[str], "nextToken": str}, total=False
)

ListInvitationsResponseTypeDef = TypedDict(
    "ListInvitationsResponseTypeDef",
    {"invitations": List["InvitationTypeDef"], "nextToken": str},
    total=False,
)

ListJobsFilterCriteriaTypeDef = TypedDict(
    "ListJobsFilterCriteriaTypeDef",
    {"excludes": List["ListJobsFilterTermTypeDef"], "includes": List["ListJobsFilterTermTypeDef"]},
    total=False,
)

ListJobsSortCriteriaTypeDef = TypedDict(
    "ListJobsSortCriteriaTypeDef",
    {
        "attributeName": Literal["createdAt", "jobStatus", "name", "jobType"],
        "orderBy": Literal["ASC", "DESC"],
    },
    total=False,
)

ListMembersResponseTypeDef = TypedDict(
    "ListMembersResponseTypeDef", {"members": List["MemberTypeDef"], "nextToken": str}, total=False
)

ListOrganizationAdminAccountsResponseTypeDef = TypedDict(
    "ListOrganizationAdminAccountsResponseTypeDef",
    {"adminAccounts": List["AdminAccountTypeDef"], "nextToken": str},
    total=False,
)

ListTagsForResourceResponseTypeDef = TypedDict(
    "ListTagsForResourceResponseTypeDef", {"tags": Dict[str, str]}, total=False
)

PutClassificationExportConfigurationResponseTypeDef = TypedDict(
    "PutClassificationExportConfigurationResponseTypeDef",
    {"configuration": "ClassificationExportConfigurationTypeDef"},
    total=False,
)

SortCriteriaTypeDef = TypedDict(
    "SortCriteriaTypeDef", {"attributeName": str, "orderBy": Literal["ASC", "DESC"]}, total=False
)

TestCustomDataIdentifierResponseTypeDef = TypedDict(
    "TestCustomDataIdentifierResponseTypeDef", {"matchCount": int}, total=False
)

UpdateFindingsFilterResponseTypeDef = TypedDict(
    "UpdateFindingsFilterResponseTypeDef", {"arn": str, "id": str}, total=False
)

UsageStatisticsFilterTypeDef = TypedDict(
    "UsageStatisticsFilterTypeDef", {"key": Literal["accountId"], "values": List[str]}, total=False
)

UsageStatisticsSortByTypeDef = TypedDict(
    "UsageStatisticsSortByTypeDef",
    {"key": Literal["accountId", "total"], "orderBy": Literal["ASC", "DESC"]},
    total=False,
)



# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
"""
Main interface for macie2 service client

Usage::

    ```python
    import boto3
    from mypy_boto3_macie2 import Macie2Client

    client: Macie2Client = boto3.client("macie2")
    ```
"""
import sys
from typing import Any, Dict, List, Type

from botocore.exceptions import ClientError as Boto3ClientError

from mypy_boto3_macie2.type_defs import (
    AccountDetailTypeDef,
    BatchGetCustomDataIdentifiersResponseTypeDef,
    BucketCriteriaAdditionalPropertiesTypeDef,
    BucketSortCriteriaTypeDef,
    ClassificationExportConfigurationTypeDef,
    CreateClassificationJobResponseTypeDef,
    CreateCustomDataIdentifierResponseTypeDef,
    CreateFindingsFilterResponseTypeDef,
    CreateInvitationsResponseTypeDef,
    CreateMemberResponseTypeDef,
    DeclineInvitationsResponseTypeDef,
    DeleteInvitationsResponseTypeDef,
    DescribeBucketsResponseTypeDef,
    DescribeClassificationJobResponseTypeDef,
    DescribeOrganizationConfigurationResponseTypeDef,
    FindingCriteriaTypeDef,
    FindingStatisticsSortCriteriaTypeDef,
    GetBucketStatisticsResponseTypeDef,
    GetClassificationExportConfigurationResponseTypeDef,
    GetCustomDataIdentifierResponseTypeDef,
    GetFindingsFilterResponseTypeDef,
    GetFindingsResponseTypeDef,
    GetFindingStatisticsResponseTypeDef,
    GetInvitationsCountResponseTypeDef,
    GetMacieSessionResponseTypeDef,
    GetMasterAccountResponseTypeDef,
    GetMemberResponseTypeDef,
    GetUsageStatisticsResponseTypeDef,
    GetUsageTotalsResponseTypeDef,
    JobScheduleFrequencyTypeDef,
    ListClassificationJobsResponseTypeDef,
    ListCustomDataIdentifiersResponseTypeDef,
    ListFindingsFiltersResponseTypeDef,
    ListFindingsResponseTypeDef,
    ListInvitationsResponseTypeDef,
    ListJobsFilterCriteriaTypeDef,
    ListJobsSortCriteriaTypeDef,
    ListMembersResponseTypeDef,
    ListOrganizationAdminAccountsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    PutClassificationExportConfigurationResponseTypeDef,
    S3JobDefinitionTypeDef,
    SortCriteriaTypeDef,
    TestCustomDataIdentifierResponseTypeDef,
    UpdateFindingsFilterResponseTypeDef,
    UsageStatisticsFilterTypeDef,
    UsageStatisticsSortByTypeDef,
)

if sys.version_info >= (3, 8):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = ("Macie2Client",)


class Exceptions:
    AccessDeniedException: Type[Boto3ClientError]
    ClientError: Type[Boto3ClientError]
    ConflictException: Type[Boto3ClientError]
    InternalServerException: Type[Boto3ClientError]
    ResourceNotFoundException: Type[Boto3ClientError]
    ServiceQuotaExceededException: Type[Boto3ClientError]
    ThrottlingException: Type[Boto3ClientError]
    ValidationException: Type[Boto3ClientError]


class Macie2Client:
    """
    [Macie2.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client)
    """

    exceptions: Exceptions

    def accept_invitation(self, invitationId: str, masterAccount: str) -> Dict[str, Any]:
        """
        [Client.accept_invitation documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.accept_invitation)
        """

    def batch_get_custom_data_identifiers(
        self, ids: List[str] = None
    ) -> BatchGetCustomDataIdentifiersResponseTypeDef:
        """
        [Client.batch_get_custom_data_identifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.batch_get_custom_data_identifiers)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.can_paginate)
        """

    def create_classification_job(
        self,
        clientToken: str,
        jobType: Literal["ONE_TIME", "SCHEDULED"],
        name: str,
        s3JobDefinition: "S3JobDefinitionTypeDef",
        customDataIdentifierIds: List[str] = None,
        description: str = None,
        initialRun: bool = None,
        samplingPercentage: int = None,
        scheduleFrequency: "JobScheduleFrequencyTypeDef" = None,
        tags: Dict[str, str] = None,
    ) -> CreateClassificationJobResponseTypeDef:
        """
        [Client.create_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.create_classification_job)
        """

    def create_custom_data_identifier(
        self,
        clientToken: str = None,
        description: str = None,
        ignoreWords: List[str] = None,
        keywords: List[str] = None,
        maximumMatchDistance: int = None,
        name: str = None,
        regex: str = None,
        tags: Dict[str, str] = None,
    ) -> CreateCustomDataIdentifierResponseTypeDef:
        """
        [Client.create_custom_data_identifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.create_custom_data_identifier)
        """

    def create_findings_filter(
        self,
        action: Literal["ARCHIVE", "NOOP"],
        findingCriteria: "FindingCriteriaTypeDef",
        name: str,
        clientToken: str = None,
        description: str = None,
        position: int = None,
        tags: Dict[str, str] = None,
    ) -> CreateFindingsFilterResponseTypeDef:
        """
        [Client.create_findings_filter documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.create_findings_filter)
        """

    def create_invitations(
        self, accountIds: List[str], disableEmailNotification: bool = None, message: str = None
    ) -> CreateInvitationsResponseTypeDef:
        """
        [Client.create_invitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.create_invitations)
        """

    def create_member(
        self, account: AccountDetailTypeDef, tags: Dict[str, str] = None
    ) -> CreateMemberResponseTypeDef:
        """
        [Client.create_member documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.create_member)
        """

    def create_sample_findings(
        self,
        findingTypes: List[
            Literal[
                "SensitiveData:S3Object/Multiple",
                "SensitiveData:S3Object/Financial",
                "SensitiveData:S3Object/Personal",
                "SensitiveData:S3Object/Credentials",
                "SensitiveData:S3Object/CustomIdentifier",
                "Policy:IAMUser/S3BucketPublic",
                "Policy:IAMUser/S3BucketSharedExternally",
                "Policy:IAMUser/S3BucketReplicatedExternally",
                "Policy:IAMUser/S3BucketEncryptionDisabled",
                "Policy:IAMUser/S3BlockPublicAccessDisabled",
            ]
        ] = None,
    ) -> Dict[str, Any]:
        """
        [Client.create_sample_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.create_sample_findings)
        """

    def decline_invitations(self, accountIds: List[str]) -> DeclineInvitationsResponseTypeDef:
        """
        [Client.decline_invitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.decline_invitations)
        """

    def delete_custom_data_identifier(self, id: str) -> Dict[str, Any]:
        """
        [Client.delete_custom_data_identifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.delete_custom_data_identifier)
        """

    def delete_findings_filter(self, id: str) -> Dict[str, Any]:
        """
        [Client.delete_findings_filter documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.delete_findings_filter)
        """

    def delete_invitations(self, accountIds: List[str]) -> DeleteInvitationsResponseTypeDef:
        """
        [Client.delete_invitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.delete_invitations)
        """

    def delete_member(self, id: str) -> Dict[str, Any]:
        """
        [Client.delete_member documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.delete_member)
        """

    def describe_buckets(
        self,
        criteria: Dict[str, BucketCriteriaAdditionalPropertiesTypeDef] = None,
        maxResults: int = None,
        nextToken: str = None,
        sortCriteria: BucketSortCriteriaTypeDef = None,
    ) -> DescribeBucketsResponseTypeDef:
        """
        [Client.describe_buckets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.describe_buckets)
        """

    def describe_classification_job(self, jobId: str) -> DescribeClassificationJobResponseTypeDef:
        """
        [Client.describe_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.describe_classification_job)
        """

    def describe_organization_configuration(
        self,
    ) -> DescribeOrganizationConfigurationResponseTypeDef:
        """
        [Client.describe_organization_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.describe_organization_configuration)
        """

    def disable_macie(self) -> Dict[str, Any]:
        """
        [Client.disable_macie documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.disable_macie)
        """

    def disable_organization_admin_account(self, adminAccountId: str) -> Dict[str, Any]:
        """
        [Client.disable_organization_admin_account documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.disable_organization_admin_account)
        """

    def disassociate_from_master_account(self) -> Dict[str, Any]:
        """
        [Client.disassociate_from_master_account documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.disassociate_from_master_account)
        """

    def disassociate_member(self, id: str) -> Dict[str, Any]:
        """
        [Client.disassociate_member documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.disassociate_member)
        """

    def enable_macie(
        self,
        clientToken: str = None,
        findingPublishingFrequency: Literal["FIFTEEN_MINUTES", "ONE_HOUR", "SIX_HOURS"] = None,
        status: Literal["PAUSED", "ENABLED"] = None,
    ) -> Dict[str, Any]:
        """
        [Client.enable_macie documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.enable_macie)
        """

    def enable_organization_admin_account(
        self, adminAccountId: str, clientToken: str = None
    ) -> Dict[str, Any]:
        """
        [Client.enable_organization_admin_account documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.enable_organization_admin_account)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Dict[str, Any] = None,
        ExpiresIn: int = 3600,
        HttpMethod: str = None,
    ) -> str:
        """
        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.generate_presigned_url)
        """

    def get_bucket_statistics(self, accountId: str = None) -> GetBucketStatisticsResponseTypeDef:
        """
        [Client.get_bucket_statistics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_bucket_statistics)
        """

    def get_classification_export_configuration(
        self,
    ) -> GetClassificationExportConfigurationResponseTypeDef:
        """
        [Client.get_classification_export_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_classification_export_configuration)
        """

    def get_custom_data_identifier(self, id: str) -> GetCustomDataIdentifierResponseTypeDef:
        """
        [Client.get_custom_data_identifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_custom_data_identifier)
        """

    def get_finding_statistics(
        self,
        groupBy: Literal[
            "resourcesAffected.s3Bucket.name",
            "type",
            "classificationDetails.jobId",
            "severity.description",
        ],
        findingCriteria: "FindingCriteriaTypeDef" = None,
        size: int = None,
        sortCriteria: FindingStatisticsSortCriteriaTypeDef = None,
    ) -> GetFindingStatisticsResponseTypeDef:
        """
        [Client.get_finding_statistics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_finding_statistics)
        """

    def get_findings(
        self, findingIds: List[str], sortCriteria: SortCriteriaTypeDef = None
    ) -> GetFindingsResponseTypeDef:
        """
        [Client.get_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_findings)
        """

    def get_findings_filter(self, id: str) -> GetFindingsFilterResponseTypeDef:
        """
        [Client.get_findings_filter documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_findings_filter)
        """

    def get_invitations_count(self) -> GetInvitationsCountResponseTypeDef:
        """
        [Client.get_invitations_count documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_invitations_count)
        """

    def get_macie_session(self) -> GetMacieSessionResponseTypeDef:
        """
        [Client.get_macie_session documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_macie_session)
        """

    def get_master_account(self) -> GetMasterAccountResponseTypeDef:
        """
        [Client.get_master_account documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_master_account)
        """

    def get_member(self, id: str) -> GetMemberResponseTypeDef:
        """
        [Client.get_member documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_member)
        """

    def get_usage_statistics(
        self,
        filterBy: List[UsageStatisticsFilterTypeDef] = None,
        maxResults: int = None,
        nextToken: str = None,
        sortBy: UsageStatisticsSortByTypeDef = None,
    ) -> GetUsageStatisticsResponseTypeDef:
        """
        [Client.get_usage_statistics documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_usage_statistics)
        """

    def get_usage_totals(self) -> GetUsageTotalsResponseTypeDef:
        """
        [Client.get_usage_totals documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.get_usage_totals)
        """

    def list_classification_jobs(
        self,
        filterCriteria: ListJobsFilterCriteriaTypeDef = None,
        maxResults: int = None,
        nextToken: str = None,
        sortCriteria: ListJobsSortCriteriaTypeDef = None,
    ) -> ListClassificationJobsResponseTypeDef:
        """
        [Client.list_classification_jobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.list_classification_jobs)
        """

    def list_custom_data_identifiers(
        self, maxResults: int = None, nextToken: str = None
    ) -> ListCustomDataIdentifiersResponseTypeDef:
        """
        [Client.list_custom_data_identifiers documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.list_custom_data_identifiers)
        """

    def list_findings(
        self,
        findingCriteria: "FindingCriteriaTypeDef" = None,
        maxResults: int = None,
        nextToken: str = None,
        sortCriteria: SortCriteriaTypeDef = None,
    ) -> ListFindingsResponseTypeDef:
        """
        [Client.list_findings documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.list_findings)
        """

    def list_findings_filters(
        self, maxResults: int = None, nextToken: str = None
    ) -> ListFindingsFiltersResponseTypeDef:
        """
        [Client.list_findings_filters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.list_findings_filters)
        """

    def list_invitations(
        self, maxResults: int = None, nextToken: str = None
    ) -> ListInvitationsResponseTypeDef:
        """
        [Client.list_invitations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.list_invitations)
        """

    def list_members(
        self, maxResults: int = None, nextToken: str = None, onlyAssociated: str = None
    ) -> ListMembersResponseTypeDef:
        """
        [Client.list_members documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.list_members)
        """

    def list_organization_admin_accounts(
        self, maxResults: int = None, nextToken: str = None
    ) -> ListOrganizationAdminAccountsResponseTypeDef:
        """
        [Client.list_organization_admin_accounts documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.list_organization_admin_accounts)
        """

    def list_tags_for_resource(self, resourceArn: str) -> ListTagsForResourceResponseTypeDef:
        """
        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.list_tags_for_resource)
        """

    def put_classification_export_configuration(
        self, configuration: "ClassificationExportConfigurationTypeDef"
    ) -> PutClassificationExportConfigurationResponseTypeDef:
        """
        [Client.put_classification_export_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.put_classification_export_configuration)
        """

    def tag_resource(self, resourceArn: str, tags: Dict[str, str]) -> Dict[str, Any]:
        """
        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.tag_resource)
        """

    def test_custom_data_identifier(
        self,
        regex: str,
        sampleText: str,
        ignoreWords: List[str] = None,
        keywords: List[str] = None,
        maximumMatchDistance: int = None,
    ) -> TestCustomDataIdentifierResponseTypeDef:
        """
        [Client.test_custom_data_identifier documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.test_custom_data_identifier)
        """

    def untag_resource(self, resourceArn: str, tagKeys: List[str]) -> Dict[str, Any]:
        """
        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.untag_resource)
        """

    def update_classification_job(
        self, jobId: str, jobStatus: Literal["RUNNING", "PAUSED", "CANCELLED", "COMPLETE", "IDLE"]
    ) -> Dict[str, Any]:
        """
        [Client.update_classification_job documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.update_classification_job)
        """

    def update_findings_filter(
        self,
        id: str,
        action: Literal["ARCHIVE", "NOOP"] = None,
        description: str = None,
        findingCriteria: "FindingCriteriaTypeDef" = None,
        name: str = None,
        position: int = None,
    ) -> UpdateFindingsFilterResponseTypeDef:
        """
        [Client.update_findings_filter documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.update_findings_filter)
        """

    def update_macie_session(
        self,
        findingPublishingFrequency: Literal["FIFTEEN_MINUTES", "ONE_HOUR", "SIX_HOURS"] = None,
        status: Literal["PAUSED", "ENABLED"] = None,
    ) -> Dict[str, Any]:
        """
        [Client.update_macie_session documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.update_macie_session)
        """

    def update_member_session(
        self, id: str, status: Literal["PAUSED", "ENABLED"]
    ) -> Dict[str, Any]:
        """
        [Client.update_member_session documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.update_member_session)
        """

    def update_organization_configuration(self, autoEnable: bool) -> Dict[str, Any]:
        """
        [Client.update_organization_configuration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.16/reference/services/macie2.html#Macie2.Client.update_organization_configuration)
        """



"""
Main interface for macie2 service.

Usage::

    ```python
    import boto3
    from mypy_boto3_macie2 import (
        Client,
        Macie2Client,
    )

    session = boto3.Session()

    client: Macie2Client = boto3.client("macie2")
    session_client: Macie2Client = session.client("macie2")
    ```
"""
from mypy_boto3_macie2.client import Macie2Client

Client = Macie2Client


__all__ = ("Client", "Macie2Client")
